@@ -64,12 +64,28 @@ FIRST_BASE_PLUS_1_CUTOFF = {
     'tzr': 4,
     'dWAR': -0.25
 }
+# -1 1B DEFENSE ONLY APPLIES TO 2022 SET AND BEYOND
+FIRST_BASE_MINUS_1_CUTOFF = {
+    'drs': -5,
+    'tzr': -5,
+    'dWAR': -1.0
+}
 # MINIMUM REQUIRED GAMES PLAYED AT A POSITION TO QUALIFY
 NUMBER_OF_GAMES_DEFENSE = 7 
 PCT_OF_GAMES_DEFENSE = 0.15
 PCT_OF_GAMES_DEFENSE_MULTI_YEAR = 0.25
 STARTING_PITCHER_PCT_GAMES_STARTED = 0.40
 CLOSER_MIN_SAVES_REQUIRED = 10
+MAX_NUMBER_OF_POSITIONS = {
+    '2000': 2,
+    '2001': 2,
+    '2002': 2,
+    '2003': 2,
+    '2004': 2,
+    '2005': 2,
+    f'2022-{CLASSIC_ALIAS}': 3,
+    f'2022-{EXPANDED_ALIAS}': 3,
+}
 
 # MULTIPLIER TO MATCH PU WITH ORIGINAL SETS
 PU_MULTIPLIER = {
@@ -106,6 +122,17 @@ GB_MULTIPLIER = {
         f'2022-{EXPANDED_ALIAS}': 1.0,
     },
 }
+# MULTIPLIER TO MATCH PU WITH ORIGINAL SETS
+HR_ROUNDING_CUTOFF = {
+    '2000': 0.85,
+    '2001': 0.85,
+    '2002': 0.85,
+    '2003': 0.85,
+    '2004': 0.85,
+    '2005': 0.85,
+    f'2022-{CLASSIC_ALIAS}': 0.75,
+    f'2022-{EXPANDED_ALIAS}': 0.75,
+}
 """
 BASELINE PITCHER VALUES
 NOTE: INDIVIDUAL RESULT CATEGORIES MAY NOT ADD UP TO 20 OR TOTAL OUTS.
@@ -172,10 +199,11 @@ BASELINE_PITCHER = {
         '3b': 0.09,
         'hr': 0.33
     },
+    # INCREASED FOR 2022 TO ACCOUNT FOR BETTER AVG PITCHING IN MLB
     f'2022-{CLASSIC_ALIAS}': {
         'command': 3.3,
         'outs': 16.0,
-        'so': 4.1,
+        'so': 5.25,
         'bb': 1.35,
         '1b': 2.0,
         '2b': 0.62,
@@ -183,9 +211,9 @@ BASELINE_PITCHER = {
         'hr': 0.11
     },
     f'2022-{EXPANDED_ALIAS}': {
-        'command': 4.0,
-        'outs': 16.0,
-        'so': 4.25,
+        'command': 4.2,
+        'outs': 16.2,
+        'so': 5.5,
         'bb': 1.25,
         '1b': 2.05,
         '2b': 0.50,
@@ -267,9 +295,9 @@ BASELINE_HITTER = {
         'hr': 1.4
     },
     f'2022-{CLASSIC_ALIAS}': {
-        'command': 8.0,
+        'command': 7.5,
         'outs': 4.0,
-        'so': 1.7,
+        'so': 2.0,
         'bb': 4.45,
         '1b': 6.7,
         '1b+': 0.63,
@@ -780,11 +808,11 @@ POINT_CATEGORY_WEIGHTS = {
     f'2022-{CLASSIC_ALIAS}': {
         'position_player': {
             'defense': 65,
-            'speed': 60,
-            'onbase': 190,
-            'average': 50,
-            'slugging': 165,
-            'home_runs': 45
+            'speed': 65,
+            'onbase': 200,
+            'average': 55,
+            'slugging': 170,
+            'home_runs': 50
         },
         'starting_pitcher': {
             'ip': 115,
@@ -805,9 +833,9 @@ POINT_CATEGORY_WEIGHTS = {
         'position_player': {
             'defense': 65,
             'speed': 60,
-            'onbase': 140,
+            'onbase': 150,
             'average': 70,
-            'slugging': 140,
+            'slugging': 150,
             'home_runs': 50
         },
         'starting_pitcher': {
@@ -1065,25 +1093,25 @@ POINTS_COMMAND_OUT_MULTIPLIER = {
         '7-3': 0.90,
 
         '2-17': 0.92,
+        '2-18': 0.95,
         '3-17': 0.85,
+        '3-18': 0.95,
         '4-14': 1.15,
         '4-15': 1.15,
-        '5-14': 1.25,
+        '5-14': 1.15,
         '6-14': 1.05,
         '6-15': 1.05,
-        '5-17': 0.99,
     },
     f'2022-{EXPANDED_ALIAS}': {
         '9-5': 1.15,
         '9-6': 1.1,
         '9-7': 0.95,
 
-        '3-15': 1.00,
-        '3-16': 1.00,
-        '3-17': 0.8,
-        '3-18': 0.9,
-        '4-17': 0.9,
-        '6-17': 1.03,
+        '1-18': 0.90,
+        '2-18': 0.90,
+        '3-17': 0.90,
+        '3-18': 0.90,
+        '4-17': 0.90,
     },
 }
 
@@ -1954,6 +1982,7 @@ TEST_OUT_RANGE_PITCHER = {
 COLOR_WHITE = "#FFFFFF"
 COLOR_BLACK = "#000000"
 COLOR_RED = "#963219"
+COLOR_GRAY = "#e4e3e3"
 
 """ COORDINATES FOR IMAGE COMPONENTS """
 IMAGE_LOCATIONS = {
@@ -2543,9 +2572,9 @@ TEAM_COLOR_PRIMARY_ALT = {
         '3': (0, 40, 120, 255),
     },
     'SFG': {
-        '1': list(range(1968,1983)),
-        '2': list(range(1983,1994)),
-        '3': list(range(1994,2000)),
+        '1': (253, 90, 30, 255),
+        '2': (253, 90, 30, 255),
+        '3': (253, 90, 30, 255),
     },
     'STL': {
         '1': (196, 30, 58, 255),
